summaryrefslogtreecommitdiff
path: root/deadbeef.h
diff options
context:
space:
mode:
authorGravatar waker <wakeroid@gmail.com>2011-05-22 12:42:21 +0200
committerGravatar waker <wakeroid@gmail.com>2011-05-22 12:42:21 +0200
commitc63133b3144cb6b52eb7d8516e31fb520e5c8924 (patch)
tree46aa922b3612406b12cbf52637b7ea101bdd9f0a /deadbeef.h
parent2660736089f1dd5d41479f27340e696edbe1944d (diff)
renamed dsp pass_through to can_bypass
Diffstat (limited to 'deadbeef.h')
-rw-r--r--deadbeef.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/deadbeef.h b/deadbeef.h
index 3b7f919b..10f50422 100644
--- a/deadbeef.h
+++ b/deadbeef.h
@@ -989,12 +989,11 @@ typedef struct DB_dsp_s {
// implemented if this is nonzero
const char *configdialog;
// pass_through is available since 1.1 api
// can be NULL
- // should return 1 if DSP plugin instance will pass data through, without
- // modification, with the current parameters;
+ // should return 1 if the DSP plugin will not touch data with the current parameters;
// 0 otherwise
- int (*pass_through) (ddb_dsp_context_t *ctx, ddb_waveformat_t *fmt);
+ int (*can_bypass) (ddb_dsp_context_t *ctx, ddb_waveformat_t *fmt);
} DB_dsp_t;
// misc plugin
@@ -989,12 +989,11 @@ typedef struct DB_dsp_s {
// implemented if this is nonzero
const char *configdialog;
- // pass_through is available since 1.1 api
+ // can_bypass is available since 1.1 api
// can be NULL